#
# spec file for package gwenview
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define plasma6_version 5.27.80
%define qt6_version 6.6.0

%bcond_without released
Name:           gwenview
Version:        24.12.2
Release:        1.2
Summary:        Image Viewer by KDE
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/gwenview
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  cfitsio-devel
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6Baloo) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemModels) >= %{kf6_version}
BuildRequires:  cmake(KDcrawQt6)
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6Purpose) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(Phonon4Qt6)
BuildRequires:  cmake(PlasmaActivities) >= %{plasma6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6OpenGLWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6SvgWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6WaylandClient) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  cmake(kImageAnnotator-Qt6)
BuildRequires:  cmake(kColorPicker-Qt6)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(x11)
Provides:       gwenview5 = %{version}
Obsoletes:      gwenview5 < %{version}
Obsoletes:      gwenview5-lang < %{version}

%description
Gwenview is an image viewer by KDE. It features a folder tree window and a file
list window, providing navigation of file hierarchies.

%lang_package

%prep
%autosetup -p1


%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-man --with-html --all-name

%ldconfig_scriptlets

%files
%license COPYING*
%doc %lang(en) %{_kf6_htmldir}/en/gwenview/
%{_kf6_applicationsdir}/org.kde.gwenview.desktop
%{_kf6_applicationsdir}/org.kde.gwenview_importer.desktop
%{_kf6_appstreamdir}/org.kde.gwenview.appdata.xml
%{_kf6_bindir}/gwenview
%{_kf6_bindir}/gwenview_importer
%{_kf6_debugdir}/gwenview.categories
%{_kf6_iconsdir}/hicolor/*/*/*
%{_kf6_libdir}/libgwenviewlib.so.*
%dir %{_kf6_plugindir}/kf6/kfileitemaction
%{_kf6_plugindir}/kf6/kfileitemaction/slideshowfileitemaction.so
%{_kf6_plugindir}/kf6/parts/gvpart.so
%{_kf6_sharedir}/gwenview/
%dir %{_kf6_sharedir}/solid
%dir %{_kf6_sharedir}/solid/actions
%{_kf6_sharedir}/solid/actions/gwenview_importer.desktop
%{_kf6_sharedir}/solid/actions/gwenview_importer_camera.desktop

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/gwenview/

%changelog
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Avoid QList clones when testing for indexed color
  * Fix color management for images in premultipled alpha format
  * Fix garbled colors when scaling indexed-color images (kde#459627)
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Fix flatpak
  * Update cfitsio
  * Don't include quiet packages in feature_summary
  * Set up crash handling
  * Add formatting commit to ignore file
  * Re-run clang-format
  * Appdata Fixes
  * Make it optional to start over after last image (kde#458332)
  * documentview: fix whatsthis KUIT context marker
  * Use KDcraw for RAW thumbnails if available
  * Fix using KDcraw for thumbnails
  * fix ODR violation: many files had the wrong definition of Enum
  * Generate wayland code with PRIVATE_CODE
  * Add missing include moc
  * Make Name Filters Search Recursively
  * Remove virtual keyword when we use override
  * Fix sizing of ToolButton in KWidgetItemDelegate
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Fix sizing of ToolButton in KWidgetItemDelegate
  * flatpak: Update cfitsio
  * Fix build with kImageAnnotator feature disabled
  * Adds a new filter ImageDimensionsFilter allowing filtering the images by their width and height.
  * Add launchable tag to appdata to fix validation
  * We use Qt6 only now
  * Change the save bar to use KMessageWidget
  * Focus the QLineEdit when showing the rename dialog
  * ImageReader: allow 2Gb max allocation
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Focus the QLineEdit when showing the rename dialog
  * ImageReader: allow 2Gb max allocation
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Fix incorrectly reversed screen saver inhibition logic (kde#481481)
  * Fix translate shortcut
  * Only set slider range when there is a valid media object (kde#483242)
  * Don't crash on unsupported fits images (kde#482615)
  * Re-enable kimageannotator integration
  * Add spotlightmode license header
  * thumbnailview: Check if thumbnail is actually visible when generating
  * thumbnailview: Don't execute thumbnail generation while we're still loading
  * Rate limit how often we update PreviewItemDelegate when model rows change
  * Update on window scale changes (kde#480659)
  * Add minimal view mode
  * org.kde.gwenview.appdata: Add developer_name & update caption
  * Fix flatpak build
  * Remove "KDE" from GenericName in the desktop file
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Fix incorrectly reversed screen saver inhibition logic (kde#481481)
  * Remove documentation that doesn't compile
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Only set slider range when there is a valid media object (kde#483242)
  * Don't crash on unsupported fits images (kde#482615)
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Re-enable kimageannotator integration
  * thumbnailview: Check if thumbnail is actually visible when generating
  * thumbnailview: Don't execute thumbnail generation while we're still loading
  * Rate limit how often we update PreviewItemDelegate when model rows change
  * Update on window scale changes (kde#480659)
  * Fix flatpak build
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/fr/announcements/megarelease/6/rc2/
* Mon Sep 11 2023 Christophe Marin <christophe@krop.fr>
- Init gwenview
